==> tfx-cli-0.1.7.tgz: package/exec/build-tasks-create.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var inputs = require('../lib/inputs');
var path = require('path');
var fs = require('fs');
var Q = require('q');
var shell = require('shelljs');
var trace = require('../lib/trace');
var uuid = require('node-uuid');
var check = require('validator');
function describe() {
    return 'create files for new build task';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([], []);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new BuildCreate();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = false;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var BuildCreate = (function (_super) {
    __extends(BuildCreate, _super);
    function BuildCreate() {
        _super.apply(this, arguments);
    }
    BuildCreate.prototype.exec = function (args, options) {
        trace('build-create.exec');
        var defer = Q.defer();
        var taskInputs = [
            {
                name: 'name',
                description: 'short name',
                arg: 'name',
                type: 'string',
                req: true
            },
            {
                name: 'friendlyName',
                description: 'friendly name',
                arg: 'friendlyName',
                type: 'string',
                req: true
            },
            {
                name: 'description',
                description: 'description',
                arg: 'description',
                type: 'string',
                req: true
            },
            {
                name: 'author',
                description: 'author',
                arg: 'author',
                type: 'string',
                req: true
            }
        ];
        inputs.Qget(taskInputs).then(function (result) {
            // validate inputs
            var tname = result['name'];
            var tfriendly = result['friendlyName'];
            var tdescription = result['description'];
            var tauthor = result['author'];
            if (!tname || !check.isAlphanumeric(tname)) {
                throw new Error('name is a required alphanumeric string with no spaces');
            }
            if (!tfriendly || !check.isLength(tfriendly, 1, 25)) {
                throw new Error('friendlyName is a required string <= 40 chars');
            }
            if (!tdescription || !check.isLength(tdescription, 1, 80)) {
                throw new Error('description is a required string <= 80 chars');
            }
            if (!tauthor || !check.isLength(tauthor, 1, 40)) {
                throw new Error('author is a required string <= 40 chars');
            }
            var ret = {};
            // create definition
            trace('creating folder for task');
            var tp = path.join(process.cwd(), tname);
            trace(tp);
            shell.mkdir('-p', tp);
            trace('created folder');
            ret.taskPath = tp;
            trace('creating definition');
            var def = {};
            def.id = uuid.v1();
            trace('id: ' + def.id);
            def.name = tname;
            trace('name: ' + def.name);
            def.friendlyName = result['friendlyName'];
            trace('friendlyName: ' + def.friendlyName);
            def.description = result['description'];
            trace('description: ' + def.description);
            def.author = result['author'];
            trace('author: ' + def.author);
            def.helpMarkDown = 'Replace with markdown to show in help';
            def.category = 'Utility';
            def.visibility = ['Build', 'Release'];
            def.demands = [];
            def.version = { Major: '0', Minor: '1', Patch: '0' };
            def.minimumAgentVersion = '1.83.0';
            def.instanceNameFormat = tname + ' $(message)';
            var cwdInput = {
                name: "cwd",
                type: "filePath",
                label: "Working Directory",
                defaultValue: "",
                required: false,
                helpMarkDown: "Current working directory when " + tname + " is run."
            };
            var msgInput = {
                name: "msg",
                type: "string",
                label: "Message",
                defaultValue: "Hello World",
                required: true,
                helpMarkDown: "Message to echo out"
            };
            def.inputs = [cwdInput, msgInput];
            def.execution = {
                Node: {
                    target: "sample.js",
                    argumentFormat: ""
                },
                PowerShell: {
                    target: "$(currentDirectory)\\sample.ps1",
                    argumentFormat: "",
                    workingDirectory: "$(currentDirectory)"
                }
            };
            ret.definition = def;
            trace('writing definition file');
            var defPath = path.join(tp, 'task.json');
            trace(defPath);
            try {
                var defStr = JSON.stringify(def, null, 2);
                trace(defStr);
                fs.writeFileSync(defPath, defStr);
            }
            catch (err) {
                throw new Error('Failed creating task: ' + err.message);
            }
            trace('created definition file.');
            var copyResource = function (fileName) {
                var src = path.join(__dirname, 'resources', fileName);
                trace('src: ' + src);
                var dest = path.join(tp, fileName);
                trace('dest: ' + dest);
                shell.cp(src, dest);
                trace(fileName + ' copied');
            };
            trace('creating temporary icon');
            copyResource('icon.png');
            copyResource('sample.js');
            copyResource('sample.ps1');
            defer.resolve(ret);
        }).fail(function (err) {
            trace('Failed to gather inputs. Message: ' + err.message);
            defer.reject(err);
        });
        return defer.promise;
    };
    BuildCreate.prototype.output = function (data) {
        if (!data) {
            throw new Error('no results');
        }
        console.log();
        console.log('created task @ ' + data.taskPath);
        var def = data.definition;
        console.log('id   : ' + def.id);
        console.log('name: ' + def.name);
        console.log();
        console.log('A temporary task icon was created.  Replace with a 32x32 png with transparencies');
    };
    return BuildCreate;
})(cmdm.TfCommand);
exports.BuildCreate = BuildCreate;

==> tfx-cli-0.1.8.tgz: package/exec/build-tasks-create.js <==
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var cmdm = require('../lib/tfcommand');
var inputs = require('../lib/inputs');
var path = require('path');
var fs = require('fs');
var Q = require('q');
var shell = require('shelljs');
var trace = require('../lib/trace');
var uuid = require('node-uuid');
var check = require('validator');
function describe() {
    return 'create files for new build task';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([], []);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new BuildCreate();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = false;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var BuildCreate = (function (_super) {
    __extends(BuildCreate, _super);
    function BuildCreate() {
        _super.apply(this, arguments);
    }
    BuildCreate.prototype.exec = function (args, options) {
        trace('build-create.exec');
        var defer = Q.defer();
        var taskInputs = [
            {
                name: 'name', description: 'short name', arg: 'name', type: 'string', req: true
            },
            {
                name: 'friendlyName', description: 'friendly name', arg: 'friendlyName', type: 'string', req: true
            },
            {
                name: 'description', description: 'description', arg: 'description', type: 'string', req: true
            },
            {
                name: 'author', description: 'author', arg: 'author', type: 'string', req: true
            }
        ];
        inputs.Qget(taskInputs)
            .then(function (result) {
            // validate inputs
            var tname = result['name'];
            var tfriendly = result['friendlyName'];
            var tdescription = result['description'];
            var tauthor = result['author'];
            if (!tname || !check.isAlphanumeric(tname)) {
                throw new Error('name is a required alphanumeric string with no spaces');
            }
            if (!tfriendly || !check.isLength(tfriendly, 1, 25)) {
                throw new Error('friendlyName is a required string <= 40 chars');
            }
            if (!tdescription || !check.isLength(tdescription, 1, 80)) {
                throw new Error('description is a required string <= 80 chars');
            }
            if (!tauthor || !check.isLength(tauthor, 1, 40)) {
                throw new Error('author is a required string <= 40 chars');
            }
            var ret = {};
            // create definition
            trace('creating folder for task');
            var tp = path.join(process.cwd(), tname);
            trace(tp);
            shell.mkdir('-p', tp);
            trace('created folder');
            ret.taskPath = tp;
            trace('creating definition');
            var def = {};
            def.id = uuid.v1();
            trace('id: ' + def.id);
            def.name = tname;
            trace('name: ' + def.name);
            def.friendlyName = result['friendlyName'];
            trace('friendlyName: ' + def.friendlyName);
            def.description = result['description'];
            trace('description: ' + def.description);
            def.author = result['author'];
            trace('author: ' + def.author);
            def.helpMarkDown = 'Replace with markdown to show in help';
            def.category = 'Utility';
            def.visibility = ['Build', 'Release'];
            def.demands = [];
            def.version = { Major: '0', Minor: '1', Patch: '0' };
            def.minimumAgentVersion = '1.83.0';
            def.instanceNameFormat = tname + ' $(message)';
            var cwdInput = {
                name: "cwd",
                type: "filePath",
                label: "Working Directory",
                defaultValue: "",
                required: false,
                helpMarkDown: "Current working directory when " + tname + " is run."
            };
            var msgInput = {
                name: "msg",
                type: "string",
                label: "Message",
                defaultValue: "Hello World",
                required: true,
                helpMarkDown: "Message to echo out"
            };
            def.inputs = [cwdInput, msgInput];
            def.execution = {
                Node: {
                    target: "sample.js",
                    argumentFormat: ""
                },
                PowerShell: {
                    target: "$(currentDirectory)\\sample.ps1",
                    argumentFormat: "",
                    workingDirectory: "$(currentDirectory)"
                }
            };
            ret.definition = def;
            trace('writing definition file');
            var defPath = path.join(tp, 'task.json');
            trace(defPath);
            try {
                var defStr = JSON.stringify(def, null, 2);
                trace(defStr);
                fs.writeFileSync(defPath, defStr);
            }
            catch (err) {
                throw new Error('Failed creating task: ' + err.message);
            }
            trace('created definition file.');
            var copyResource = function (fileName) {
                var src = path.join(__dirname, 'resources', fileName);
                trace('src: ' + src);
                var dest = path.join(tp, fileName);
                trace('dest: ' + dest);
                shell.cp(src, dest);
                trace(fileName + ' copied');
            };
            trace('creating temporary icon');
            copyResource('icon.png');
            copyResource('sample.js');
            copyResource('sample.ps1');
            defer.resolve(ret);
        })
            .fail(function (err) {
            trace('Failed to gather inputs. Message: ' + err.message);
            defer.reject(err);
        });
        return defer.promise;
    };
    BuildCreate.prototype.output = function (data) {
        if (!data) {
            throw new Error('no results');
        }
        console.log();
        console.log('created task @ ' + data.taskPath);
        var def = data.definition;
        console.log('id   : ' + def.id);
        console.log('name: ' + def.name);
        console.log();
        console.log('A temporary task icon was created.  Replace with a 32x32 png with transparencies');
    };
    return BuildCreate;
})(cmdm.TfCommand);
exports.BuildCreate = BuildCreate;
